@@ -120,6 +120,9 @@ class Either(Generic[A, B], metaclass=ABCMeta):
             lambda right: f(right.value)
         )
 
+    def __lshift__(self, f: "Callable[[B], Either[AA, C]]") -> "Either[Union[A, AA], C]":
+        return self.flat_map(f)
+
     def flatten(self: "Either[A1, Either[AA, BB]]") -> "Either[Union[A1, AA], BB]":
         return self.flat_map(lambda x: x)
 
@@ -284,6 +287,9 @@ class EitherArrow(Generic[P, A, B]):
     def flat_map(self, f: "Callable[[B], Either[AA, C]]") -> "EitherArrow[P, Union[A, AA], C]":
         return EitherArrow(lambda *args, **kwargs: self._f(*args, **kwargs).flat_map(f))
 
+    def __lshift__(self, f: "Callable[[B], Either[AA, C]]") -> "EitherArrow[P, Union[A, AA], C]":
+        return self.flat_map(f)
+
     def flatten(
         self: "EitherArrow[P, A1, Either[AA, BB]]"
     ) -> "EitherArrow[P, Union[A1, AA], BB]":
@@ -307,6 +313,14 @@ class EitherArrow(Generic[P, A, B]):
             lambda *args, **kwargs: self._f(*args, **kwargs).asserting(predicate, to_error)
         )
 
+    def or_else(self, other: "EitherArrow[P, AA, BB]") -> "EitherArrow[P, A | AA, B | BB]":
+        return EitherArrow(
+            lambda *args, **kwargs: self._f(*args, **kwargs).match(
+                lambda _: other(*args, **kwargs),
+                lambda a: a
+            )
+        )
+
     def raise_errors(self: "EitherArrow[P, AA, BB]") -> "EitherArrow[P, NoReturn, BB]":
         return EitherArrow(lambda *args, **kwargs: self._f(*args, **kwargs).raise_errors())
 
