@@ -89,7 +89,7 @@ class LiveConsole(Console):
 
 
 class MockConsole(Console):
-    def __init__(self, user_input: List[Union[EOFError, KeyboardInterrupt, str]] = None) -> None:
+    def __init__(self, user_input: Optional[List[Union[EOFError, KeyboardInterrupt, str]]] = None) -> None:
         self._effects: List[Union[console_effect.Print, console_effect.Input]] = []
         if user_input is None:
             user_input = []
