@@ -184,7 +184,7 @@ class ZIO(Generic[R, E, A]):
         )
 
 
-class Environment(Generic[R], ZIO[R, NoReturn, R]):
+class Environment(Generic[RR], ZIO[RR, NoReturn, RR]):
     def __init__(self) -> None:
         self._run = lambda r: Right(r)
 
